# AEMET OpenData Python API

[![Latest Version][mdversion-button]][md-pypi]
[![Python Versions][pyversion-button]][md-pypi]
[![License: GPL v2][gpl2-button]](LICENSE.md)

[gpl2-button]: https://img.shields.io/badge/License-GPL%20v2-blue.svg
[md-pypi]: https://pypi.org/project/AEMET-OpenData
[mdversion-button]: https://img.shields.io/pypi/v/AEMET-OpenData.svg
[pyversion-button]: https://img.shields.io/pypi/pyversions/AEMET-OpenData.svg

Python client for the AEMET OpenData Rest API.

## Description

AEMET-OpenData is a Python module implementing an interface to the AEMET OpenData Rest API.<br/>
It allows a user to gather all the public weather information from AEMET (Agencia Estatal de Meteorología).

Documentation for the AEMET OpenData Rest API is available at https://opendata.aemet.es/.

This package has been developed to be used with [Home-Assistant](https://home-assistant.io/) but it can be used in other contexts.

## Disclaimer

AEMET-OpenData was created for my own use, and for others who may wish to experiment with personal Internet of Things systems.

I have no connection with AEMET. I receive no help (financial or otherwise) from AEMET, and have no business interest with them.

This software is provided without warranty, according to the GNU Public Licence version 2, and should therefore not be used where it may endanger life, financial stakes, or cause discomfort and inconvenience to others.

## Requirements
- Python >= 3.11

## Install
```bash
pip install aioairzone-cloud
```

## Install from Source
Run the following command inside this folder
```bash
pip install --upgrade .
```

## Examples
Examples can be found in the `examples` folder
